# Pinocchio by Carlo Colodi (*The Tale of a Puppet*)

## Chapter 1

### THE PIECE OF WOOD THAT LAUGHED AND CRIED LIKE A CHILD

There was once upon a time a piece of wood in the shop of an old carpenter named Master Antonio. Everybody, however, called him Master Cherry, on account of the end of his nose, which was always as red and polished as a ripe cherry.

No sooner had Master Cherry set eyes on the piece of wood than his face beamed with delight, and, rubbing his hands together with satisfaction, he said softly to himself:

"This wood has come at the right moment; it will just do to make the leg of a little table."

He immediately took a sharp axe with which to remove the bark and the rough surface, but just as he was going to give the first stroke he heard a very small voice say imploringly, "Do not strike me so hard!"

He turned his terrified eyes all around the room to try and discover where the little voice could possibly have come from, but he saw nobody! He looked under the bench—nobody; he looked into a cupboard that was always shut—nobody; he looked into a basket of shavings and sawdust—nobody; he even opened the door of the shop and gave a glance into the street—and still nobody. Who, then, could it be?

"I see how it is," he said, laughing and scratching his wig, "evidently that little voice was all my imagination. Let us set to work again."

And, taking up the axe, he struck a tremendous blow on the piece of wood.

"Oh! oh! you have hurt me!" cried the same little voice dolefully.

This time Master Cherry was petrified. His eyes started out of his head with fright, his mouth remained open, and his tongue hung out almost to the end of his chin, like a mask on a fountain. As soon as he had recovered the use of his speech he began to say, stuttering and trembling with fear:

"But where on earth can that little voice have come from that said 'Oh! oh!'? Is it possible that this piece of wood can have learned to cry and to lament like a child? I cannot believe it. This piece of wood is nothing but a log for fuel like all the others, and thrown on the fire it would about suffice to boil a saucepan of beans. How then? Can anyone be hidden inside it? If anyone is hidden inside, so much the worse for him. I will settle him at once."

So saying, he seized the poor piece of wood and commenced beating it without mercy against the walls of the room.

Then he stopped to listen if he could hear any little voice lamenting. He waited two minutes—nothing; five minutes—nothing; ten minutes—still nothing!

"I see how it is," he then said, forcing himself to laugh, and pushing up his wig; "evidently the little voice that said 'Oh! oh!' was all my imagination! Let us set to work again."

Putting the axe aside, he took his plane, to plane and polish the bit of wood; but whilst he was running it up and down he heard the same little voice say, laughing:

"Stop! you are tickling me all over!"

This time poor Master Cherry fell down as if he had been struck by lightning. When he at last opened his eyes he found himself seated on the floor.

His face was changed, even the end of his nose, instead of being crimson, as it was nearly always, had become blue from fright.

## Chapter 2

### MASTER CHERRY GIVES THE WOOD AWAY

At that moment some one knocked at the door.

"Come in," said the carpenter, without having the strength to rise to his feet.

A lively little old man immediately walked into the shop. His name was Geppetto, but when the boys of the neighborhood wished to make him angry they called him Pudding, because his yellow wig greatly resembled a pudding made of Indian corn.

Geppetto was very fiery. Woe to him who called him Pudding! He became furious and there was no holding him.

"Good-day, Master Antonio," said Geppetto; "what are you doing there on the floor?"

"I am teaching the alphabet to the ants."

"Much good may that do you."

"What has brought you to me, neighbor Geppetto?"

"My legs. But to tell the truth. Master Antonio, I came to ask a favor of you."

"Here I am, ready to serve you," replied the carpenter, getting on his knees.

"This morning an idea came into my head."

"Let us hear it."

"I thought I would make a beautiful wooden puppet; one that could dance, fence, and leap like an acrobat. With this puppet I would travel about the world to earn a piece of bread and a glass of wine. What do you think of it?"

"Bravo, Pudding!" exclaimed the same little voice, and it was impossible to say where it came from.

Hearing himself called Pudding, Geppetto became as red as a turkey-cock from rage and, turning to the carpenter, he said in a fury:

"Why do you insult me?"

"Who insults you?"

"You called me Pudding!"

"It was not I!"

"Do you think I called myself Pudding? It was you, I say!"

"No!"

"Yes!"

"No!"

"Yes!"

And, becoming more and more angry, from words they came to blows, and, flying at each other, they bit and fought, and scratched.

When the fight was over Master Antonio was in possession of Geppetto's yellow wig, and Geppetto discovered that the grey wig belonging to the carpenter remained between his teeth.

"Give me back my wig," screamed Master Antonio.

"And you, return me mine, and let us be friends again."

The two old men having each recovered his own wig, shook hands and swore that they would remain friends to the end of their lives.

"Well, then, neighbor Geppetto," said the carpenter, to prove that peace was made, "what is the favor that you wish of me?"

"I want a little wood to make my puppet; will you give me some?"

Master Antonio was delighted, and he immediately went to the bench and fetched the piece of wood that had caused him so much fear. But just as he was going to give it to his friend the piece of wood gave a shake and, wriggling violently out of his hands, struck with all of its force against the dried-up shins of poor Geppetto.

"Ah! is that the courteous way in which you make your presents, Master Antonio? You have almost lamed me!"

"I swear to you that it was not I!"

"Then you would have it that it was I?"

"The wood is entirely to blame!"

"I know that it was the wood; but it was you that hit my legs with it!"

"I did not hit you with it!"

"Liar!"

"Geppetto, don't insult me or I will call you Pudding!"

"Knave!"

"Pudding!"

"Donkey!"

"Pudding!"

"Baboon!"

"Pudding!"

On hearing himself called Pudding for the third time Geppetto, mad with rage, fell upon the carpenter and they fought desperately.

When the battle was over, Master Antonio had two more scratches on his nose, and his adversary had lost two buttons off his waistcoat. Their accounts being thus squared, they shook hands and swore to remain good friends for the rest of their lives.

Geppetto carried off his fine piece of wood and, thanking Master Antonio, returned limping to his house.